@@ -1,5 +1,5 @@
 (* approx: proxy server for Debian archive files
-   Copyright (C) 2006  Eric C. Cooper <ecc@cmu.edu>
+   Copyright (C) 2007  Eric C. Cooper <ecc@cmu.edu>
    Released under the GNU General Public License *)
 
 val config_file : string
@@ -10,4 +10,8 @@ val port : int
 val interval : int  (* minutes *)
 val max_wait : int  (* seconds *)
 val max_rate : string  (* bytes/second with optional K, M, or G suffix *)
+val user : string
+val group : string
+val syslog : string
+val verbose : bool
 val debug : bool
