@@ -1,5 +1,5 @@
 (* approx: proxy server for Debian archive files
-   Copyright (C) 2006  Eric C. Cooper <ecc@cmu.edu>
+   Copyright (C) 2007  Eric C. Cooper <ecc@cmu.edu>
    Released under the GNU General Public License *)
 
 (* Extract substring s.[from] .. s.[until-1] *)
@@ -96,7 +96,7 @@ val file_sha256sum : string -> string
 
 (* Drop privileges (user and group ID) to those of the specified name *)
 
-val drop_privileges : string -> unit
+val drop_privileges : user:string -> group:string -> unit
 
 (* Check whether a file is a Sources file *)
 
